summaryrefslogtreecommitdiffstats
path: root/python-ethtool/ethtool.c
diff options
context:
space:
mode:
Diffstat (limited to 'python-ethtool/ethtool.c')
-rw-r--r--python-ethtool/ethtool.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/python-ethtool/ethtool.c b/python-ethtool/ethtool.c
index 4701308..e58d5f9 100644
--- a/python-ethtool/ethtool.c
+++ b/python-ethtool/ethtool.c
@@ -962,7 +962,9 @@ PyMODINIT_FUNC initethtool(void)
Py_INCREF(&ethtool_etherinfoType);
PyModule_AddObject(m, "etherinfo", (PyObject *)&ethtool_etherinfoType);
- // Prepare the ethtool IPv4 address types
+ // Prepare the ethtool IPv6 and IPv4 address types
+ if (PyType_Ready(&ethtool_netlink_ipv6_address_Type) < 0)
+ return;
if (PyType_Ready(&ethtool_netlink_ipv4_address_Type))
return;